diff --git a/BodyshopUploader/App.config b/BodyshopUploader/App.config
index 986065c..93e04ab 100644
--- a/BodyshopUploader/App.config
+++ b/BodyshopUploader/App.config
@@ -2,7 +2,7 @@
-
+
@@ -41,7 +41,7 @@
-
+
@@ -81,6 +81,6 @@
0
-
+
diff --git a/BodyshopUploader/App.xaml b/BodyshopUploader/App.xaml
index c14eee4..d1ed206 100644
--- a/BodyshopUploader/App.xaml
+++ b/BodyshopUploader/App.xaml
@@ -1,7 +1,7 @@
-
/// Interaction logic for App.xaml
///
public partial class App : Application
{
- static Mutex mutex = new Mutex(false, "ImEX Online Partner");
+ static Mutex mutex = new Mutex(false, "Rome Online Partner");
App()
{
@@ -31,7 +31,7 @@ namespace BodyshopPartner
// of the program is in the process of shutting down.
if (!mutex.WaitOne(TimeSpan.FromSeconds(2), false))
{
- MessageBox.Show("ImEX Online Partner is already running.");
+ MessageBox.Show("Rome Online Partner is already running.");
App.Current.Shutdown();
return;
}
@@ -48,7 +48,7 @@ namespace BodyshopPartner
mutex.ReleaseMutex();
Utils.PowerModeEventHandler.DisposeEventHandler();
- BodyshopPartner.Properties.Settings.Default.Save();
+ RomeOnlinePartner.Properties.Settings.Default.Save();
Utils.QuickBooksInterop.DisconnectFromQuickBooks();
}
}
diff --git a/BodyshopUploader/Assets/ro-favicon.ico b/BodyshopUploader/Assets/ro-favicon.ico
new file mode 100644
index 0000000..e9fe40c
Binary files /dev/null and b/BodyshopUploader/Assets/ro-favicon.ico differ
diff --git a/BodyshopUploader/Assets/ro-favicon.png b/BodyshopUploader/Assets/ro-favicon.png
new file mode 100644
index 0000000..ed943a5
Binary files /dev/null and b/BodyshopUploader/Assets/ro-favicon.png differ
diff --git a/BodyshopUploader/ImEXOnlinePartner.csproj b/BodyshopUploader/ImEXOnlinePartner.csproj
index 54b960f..e1de7e2 100644
--- a/BodyshopUploader/ImEXOnlinePartner.csproj
+++ b/BodyshopUploader/ImEXOnlinePartner.csproj
@@ -6,8 +6,8 @@
AnyCPU
{76B98E9B-A33A-464F-A07B-56E773376543}
WinExe
- BodyshopPartner
- ImEXOnlinePartner
+ RomeOnlinePartner
+ RomeOnlinePartner
v4.8
512
{60dc8134-eba5-43b8-bcc9-bb4bc16c2548};{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}
@@ -54,7 +54,7 @@
4
- favicon.ico
+ Assets\ro-favicon.ico
true
@@ -80,7 +80,7 @@
- BodyshopPartner.App
+ RomeOnlinePartner.App
bin\Test\
@@ -270,6 +270,8 @@
+
+
PreserveNewest
@@ -558,7 +560,7 @@
-
-
+
+
\ No newline at end of file
diff --git a/BodyshopUploader/Models/Bodyshop.cs b/BodyshopUploader/Models/Bodyshop.cs
index aa6bc3b..824cca6 100644
--- a/BodyshopUploader/Models/Bodyshop.cs
+++ b/BodyshopUploader/Models/Bodyshop.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
[JsonConverter(typeof(Utils.JsonPathConverter))]
public class Bodyshop : DTO_Base
diff --git a/BodyshopUploader/Models/DTO_Base.cs b/BodyshopUploader/Models/DTO_Base.cs
index a240043..6443f2b 100644
--- a/BodyshopUploader/Models/DTO_Base.cs
+++ b/BodyshopUploader/Models/DTO_Base.cs
@@ -6,7 +6,7 @@ using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public abstract class DTO_Base : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Models/DTO_QueueItem.cs b/BodyshopUploader/Models/DTO_QueueItem.cs
index d3b74db..d2966ad 100644
--- a/BodyshopUploader/Models/DTO_QueueItem.cs
+++ b/BodyshopUploader/Models/DTO_QueueItem.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner
+namespace RomeOnlinePartner
{
public enum SourceSystem
{
@@ -14,7 +14,7 @@ namespace BodyshopPartner
}
}
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class DTO_QueueItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/Monitor.cs b/BodyshopUploader/Models/Monitor.cs
index 7120ed1..c6afc12 100644
--- a/BodyshopUploader/Models/Monitor.cs
+++ b/BodyshopUploader/Models/Monitor.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class Monitor : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbRequestItem.cs b/BodyshopUploader/Models/QbRequestItem.cs
index c96f4e3..67bc872 100644
--- a/BodyshopUploader/Models/QbRequestItem.cs
+++ b/BodyshopUploader/Models/QbRequestItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class QbRequestItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbResponseItem.cs b/BodyshopUploader/Models/QbResponseItem.cs
index 9c43cde..40acadc 100644
--- a/BodyshopUploader/Models/QbResponseItem.cs
+++ b/BodyshopUploader/Models/QbResponseItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class QbResponseItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbXmlResponse.cs b/BodyshopUploader/Models/QbXmlResponse.cs
index a79858e..2e4ae6e 100644
--- a/BodyshopUploader/Models/QbXmlResponse.cs
+++ b/BodyshopUploader/Models/QbXmlResponse.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class QbXmlResponse : DTO_Base
{
diff --git a/BodyshopUploader/Models/ScanResponseItem.cs b/BodyshopUploader/Models/ScanResponseItem.cs
index 5c77d0e..042a2f5 100644
--- a/BodyshopUploader/Models/ScanResponseItem.cs
+++ b/BodyshopUploader/Models/ScanResponseItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace BodyshopPartner.Models
+namespace RomeOnlinePartner.Models
{
public class ScanResponseItem : DTO_Base
{
diff --git a/BodyshopUploader/Properties/AssemblyInfo.cs b/BodyshopUploader/Properties/AssemblyInfo.cs
index 38d4db7..319d6da 100644
--- a/BodyshopUploader/Properties/AssemblyInfo.cs
+++ b/BodyshopUploader/Properties/AssemblyInfo.cs
@@ -7,11 +7,11 @@ using System.Windows;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("ImEX Online Partner")]
+[assembly: AssemblyTitle("Rome Online Partner")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("ImEX Systems Inc.")]
-[assembly: AssemblyProduct("ImEX Online Partner")]
+[assembly: AssemblyCompany("Rome Technologies")]
+[assembly: AssemblyProduct("Rome Online Partner")]
[assembly: AssemblyCopyright("Copyright © ImEX Systems Inc.")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/BodyshopUploader/Properties/Resources.resx b/BodyshopUploader/Properties/Resources.resx
index bdda7b9..c599f83 100644
--- a/BodyshopUploader/Properties/Resources.resx
+++ b/BodyshopUploader/Properties/Resources.resx
@@ -163,10 +163,10 @@
Browse for QuickBooks File
- Browse Paint Scale -> IO Path
+ Browse Paint Scale -> RO Path
- Browse IO-> Paint Scale Path
+ Browse RO-> Paint Scale Path
(Re)configure ARMS Export
@@ -187,13 +187,13 @@
Monitor Status
- Paint Scale -> IO Path
+ Paint Scale -> RO Path
Paint Scare Import Timer (mins)
- IO ->Paint Scale Path
+ RO ->Paint Scale Path
QuickBooks File Path
@@ -247,7 +247,7 @@
QuickBooks Connection
- Please do not close ImEX Online or ImEX Partner during the connection process.
+ Please do not close Rome Online or Rome Partner during the connection process.
QuickBooks Connection Request
@@ -262,13 +262,13 @@
Password
- Login -ImEX Online Partner
+ Login - Rome Online Partner
- ImEX Online Partner
+ Rome Online Partner
- ImEX Online Partner | ImEX Systems Inc.
+ Rome Online Partner | Rome Technologies
Username
diff --git a/BodyshopUploader/Properties/Settings.Designer.cs b/BodyshopUploader/Properties/Settings.Designer.cs
index 6b778b1..e5777fb 100644
--- a/BodyshopUploader/Properties/Settings.Designer.cs
+++ b/BodyshopUploader/Properties/Settings.Designer.cs
@@ -8,7 +8,7 @@
//
//------------------------------------------------------------------------------
-namespace BodyshopPartner.Properties {
+namespace RomeOnlinePartner.Properties {
[global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
diff --git a/BodyshopUploader/Properties/Settings.settings b/BodyshopUploader/Properties/Settings.settings
index 0b2bddf..2c58d3d 100644
--- a/BodyshopUploader/Properties/Settings.settings
+++ b/BodyshopUploader/Properties/Settings.settings
@@ -1,5 +1,5 @@
-
+
diff --git a/BodyshopUploader/Releases/RELEASES b/BodyshopUploader/Releases/RELEASES
index 8ebb21d..1342cba 100644
--- a/BodyshopUploader/Releases/RELEASES
+++ b/BodyshopUploader/Releases/RELEASES
@@ -1,77 +1 @@
-CC5A9E1708874E6ACB29A5622DFD9C5772230727 ImEXOnlinePartner-1.0.0-full.nupkg 4937580
-7C5340F2B41ECAAA84BEE8ACD790135A64485D29 ImEXOnlinePartner-1.0.1-delta.nupkg 36746
-DCD839653F086BCA57F1D32A5235FFD63656E828 ImEXOnlinePartner-1.0.1-full.nupkg 4936984
-AF4689DFA19C7EAC5E1F03DFCF298A05B550198B ImEXOnlinePartner-1.0.2-delta.nupkg 30212
-F2D64AFC971565D6A6AB3C69D39918BA651D2BB3 ImEXOnlinePartner-1.0.2-full.nupkg 4938834
-B28BABEA8C23215EE92CD691B8F69CEEC40D04C8 ImEXOnlinePartner-1.0.3-delta.nupkg 30700
-CA43E2BC60A8A67126609C5682AA3D39D68D2400 ImEXOnlinePartner-1.0.3-full.nupkg 4935967
-46500AB5ADA0E5E7367EE77C708977BDFA2BDD4D ImEXOnlinePartner-1.0.4-delta.nupkg 48821
-CB63B87719141FDE534A108AC6831B707AB064DE ImEXOnlinePartner-1.0.4-full.nupkg 4938065
-C5117C0E0E58EF10C4FA6104274493FBFD231362 ImEXOnlinePartner-1.0.5-delta.nupkg 40888
-A1502201673BAFC13E7A3A5B398124B6A484F545 ImEXOnlinePartner-1.0.5-full.nupkg 4938758
-00D39717165B0CF3C5DA1977D5B5DF59A7627564 ImEXOnlinePartner-1.0.6-delta.nupkg 23256
-832B7905507DFAC0BC07328EB815BF20CBD8BB49 ImEXOnlinePartner-1.0.6-full.nupkg 4938826
-B57CD4F194E5466C141165FBF4311D0232DB9FF8 ImEXOnlinePartner-1.0.7-delta.nupkg 48049
-E0698E0CC34D4C4935F2203A5FBD0FD0689950F4 ImEXOnlinePartner-1.0.7-full.nupkg 4941364
-3CF98AE0E5F8C8657D762D9E125A4F864FD0F08D ImEXOnlinePartner-1.0.8-delta.nupkg 35469
-016A144E3F11A8494A9F90CF628DCD6FCAB5B962 ImEXOnlinePartner-1.0.8-full.nupkg 4942347
-4DB8C0F3DCADA02053283379BFE2EDBEBB8E5CAE ImEXOnlinePartner-1.0.9-delta.nupkg 43719
-C49C53B522F40B10C7DD68976A272CBFBA3FB780 ImEXOnlinePartner-1.0.9-full.nupkg 4941918
-2773D5E14A52247AAC34D85A27DDC02BB0292872 ImEXOnlinePartner-1.0.10-delta.nupkg 1421541
-FA38CDB780F139BFE53BA4040EEC198F0526CE1B ImEXOnlinePartner-1.0.10-full.nupkg 5906091
-B267713EE688D7AE11DF601300DD009BE489C3F7 ImEXOnlinePartner-1.0.11-delta.nupkg 91294
-234F7CBCDE952C8B418EC3914DF14A8478F6FE60 ImEXOnlinePartner-1.0.11-full.nupkg 5909542
-11E3C5D192C4832CFBE46243BB7AA36B27BF3C4C ImEXOnlinePartner-1.0.13-delta.nupkg 29519
-B5D1B3BBD5962AE5AE9650B50956C8CF8C5EBEB9 ImEXOnlinePartner-1.0.13-full.nupkg 5147044
-AFC97D32A72155DDCDC9FA0C42E0E0309FD80E1A ImEXOnlinePartner-1.0.14-delta.nupkg 52030
-3D90B05D7BF821194DF934A09DE33CD850350148 ImEXOnlinePartner-1.0.14-full.nupkg 5147961
-8A9B92246C6518FE21644AADF548FDDD18548812 ImEXOnlinePartner-1.0.15-delta.nupkg 45479
-08370231115AB8CBAF7F96F73096C76250BCB6DB ImEXOnlinePartner-1.0.15-full.nupkg 5148126
-8470C73928BF9AC9390CD45DA08B2BDD7A5568E5 ImEXOnlinePartner-1.0.16-delta.nupkg 50005
-05F6DD20D20E33AE9589E42397C63BBCACD428B0 ImEXOnlinePartner-1.0.16-full.nupkg 5149052
-6E1FF9DBDACF7FCD499CA8CCA8B6252208878A9B ImEXOnlinePartner-1.0.17-delta.nupkg 50415
-A9081BA70BD2247EB20FC11BC55506C92873323B ImEXOnlinePartner-1.0.17-full.nupkg 5152981
-C2BD7AD989BBE3A6D16D6BB0790E611FC1C43A2C ImEXOnlinePartner-1.0.18-delta.nupkg 192001
-D62C10039629E09EC5343B530503D1E2DC1EEBD4 ImEXOnlinePartner-1.0.18-full.nupkg 5158717
-390A447A753333F560D01B73FC22B4D0A53343E7 ImEXOnlinePartner-1.0.19-delta.nupkg 37769
-2B86634D71112809C91C1F1A5CC4119B4A0F4EC6 ImEXOnlinePartner-1.0.19-full.nupkg 5158927
-7A2159A7C739BEB084EF7763623C190521728D52 ImEXOnlinePartner-1.0.20-delta.nupkg 76101
-62DC1CCB2F8BB766C04DDA46B22BD4A6CFF0ABB5 ImEXOnlinePartner-1.0.20-full.nupkg 5198592
-11009A195489F6147BDB4C3563070FFB06303FBF ImEXOnlinePartner-1.0.21-delta.nupkg 26577
-95F57B9083321F21259FE125B3A152BB171BD4EC ImEXOnlinePartner-1.0.21-full.nupkg 5189950
-B80473EA2E60AFE03F0E22E2C78995A2360D9DB7 ImEXOnlinePartner-1.0.22-delta.nupkg 26086
-C15C0B6EE335E383F2CEF0EFA32027B7210AA312 ImEXOnlinePartner-1.0.22-full.nupkg 5189952
-05DE59E77109F985B45F4F7111B170A5BB79568F ImEXOnlinePartner-1.0.23-delta.nupkg 338352
-9FC3D7604BD9356F5ED8302FA9F256B43EDF4491 ImEXOnlinePartner-1.0.23-full.nupkg 5309975
-4ACCFC490941BDDE71896FE47E5E4B8ACA293CD8 ImEXOnlinePartner-1.0.24-delta.nupkg 31450
-187BA94ACAE7FBF770D1D2894FF3A2F13831E7B3 ImEXOnlinePartner-1.0.24-full.nupkg 5303976
-8E9C189C1D8D768FEA5E3E4B6726C1591F50026D ImEXOnlinePartner-1.0.25-delta.nupkg 58605
-F502E648C6A0C95ED82247B106CC2D6CBF14BFA6 ImEXOnlinePartner-1.0.25-full.nupkg 5303888
-3E5481B1FFA814BF5BAE995F1CF54A7B9C57AAF7 ImEXOnlinePartner-1.0.26-delta.nupkg 246927
-83CF6EBEB7A28CCA28633494874C9F3C19ABEF64 ImEXOnlinePartner-1.0.26-full.nupkg 5474941
-426B816DF1D2B9D4C4CEE830C66CE6744C0E4F02 ImEXOnlinePartner-1.0.27-delta.nupkg 75385
-FF8A2B1EF451CEDB05366A6C119C6CE4E1CBAD58 ImEXOnlinePartner-1.0.27-full.nupkg 5454463
-8A30908F64F1BF1FEE2E4E4455BEE7EF3B919FF7 ImEXOnlinePartner-1.0.28-delta.nupkg 180302
-CA63387A44437B55CD283AB4A2CB92385F1321E7 ImEXOnlinePartner-1.0.28-full.nupkg 5509349
-36869986F57C7F0E25610A10F43C740DAC7639A2 ImEXOnlinePartner-1.0.29-delta.nupkg 56217
-6F104EF819C1791FD334CE21CEE9C6B8DB3FC105 ImEXOnlinePartner-1.0.29-full.nupkg 5510931
-D441404BE86E0A676462DD367D4355894C2FFDBA ImEXOnlinePartner-1.0.30-delta.nupkg 62664
-66963D1624BD0C662CDF6E93B87D9AE4FA8073FF ImEXOnlinePartner-1.0.30-full.nupkg 5512346
-8F1739F9B7C202F7E2453E7D5027F7422637D206 ImEXOnlinePartner-1.0.31-delta.nupkg 152092
-6B3D3A0DD81D6F0C302ACE42DEDDDFC11270DD22 ImEXOnlinePartner-1.0.31-full.nupkg 5609086
-9DA03F46A6BB7040C98C7DE9F308562031D790FE ImEXOnlinePartner-1.0.32-delta.nupkg 85634
-3B840B836E8F3F9C15C7F75AE9CE393C42FFB1AA ImEXOnlinePartner-1.0.32-full.nupkg 5607667
-5C61CDF97FA03C44FF74EE4E2EE4514177CE1326 ImEXOnlinePartner-1.0.33-delta.nupkg 43893
-01123C15D95479FCE91F2C24CCEFEE4F08A6FC8A ImEXOnlinePartner-1.0.33-full.nupkg 5608151
-48AB8CC396744B4A8A4C18009104D4F34A51D8C3 ImEXOnlinePartner-1.0.34-delta.nupkg 41320
-F487943208C465042E626845FF729EAAA2260DD0 ImEXOnlinePartner-1.0.34-full.nupkg 5608469
-B835758C6578EFEC019A75E242B9C767A4724500 ImEXOnlinePartner-1.0.35-delta.nupkg 326566
-FC21A9F7119BEA8FF5368634B54AC42CD3CD1C52 ImEXOnlinePartner-1.0.35-full.nupkg 5836055
-BC2315F9A364B91A5F478D49F499BFD8806E6330 ImEXOnlinePartner-1.0.36-delta.nupkg 39139
-39DE207674CA35CB33EDF768BC794D8FB37351AF ImEXOnlinePartner-1.0.36-full.nupkg 5834701
-2F45F8418180E1F794EF5C8C67C6CC25A3C68BFA ImEXOnlinePartner-1.0.37-delta.nupkg 388092
-6286F1D7E794039C9F2387D0224E8113811ABB1A ImEXOnlinePartner-1.0.37-full.nupkg 5956583
-2A60B2531CC36DE6204CB789CFCEE7353EF68C3F ImEXOnlinePartner-1.0.38-delta.nupkg 63053
-50E14718FC27BBC78C5356FAA9DC0A7329514184 ImEXOnlinePartner-1.0.38-full.nupkg 5952088
-8FF329C7011F735FB8F190CC0C46188919E0C608 ImEXOnlinePartner-1.0.39-delta.nupkg 39124
-4651DF307A68D0D7A68FE4832C1298B7D31D3A3A ImEXOnlinePartner-1.0.39-full.nupkg 5950736
\ No newline at end of file
+C933D8EE457340B141EDAD2DD461818948A06AB6 RomeOnlinePartner-1.1.0-full.nupkg 5955242
\ No newline at end of file
diff --git a/BodyshopUploader/RomeOnlinePartner.nuspec b/BodyshopUploader/RomeOnlinePartner.nuspec
new file mode 100644
index 0000000..5d07a70
--- /dev/null
+++ b/BodyshopUploader/RomeOnlinePartner.nuspec
@@ -0,0 +1,18 @@
+
+
+
+ RomeOnlinePartner
+ 1.0.0
+ Rome Online Partner
+ ImEX Systems Inc.
+
+ false
+ https://s3.us-east-2.amazonaws.com/partner.romeonline.io/favicon.ico
+ ImEX Systems Inc.
+ Rome Online Partner
+
+
+
+
+
+
\ No newline at end of file
diff --git a/BodyshopUploader/Utils/ARMSRoData.cs b/BodyshopUploader/Utils/ARMSRoData.cs
index 3325699..93107be 100644
--- a/BodyshopUploader/Utils/ARMSRoData.cs
+++ b/BodyshopUploader/Utils/ARMSRoData.cs
@@ -10,7 +10,7 @@ using GraphQL;
using Newtonsoft;
using Newtonsoft.Json.Linq;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class ARMSRoData
{
diff --git a/BodyshopUploader/Utils/ARMSRoDataModel.cs b/BodyshopUploader/Utils/ARMSRoDataModel.cs
index d3999c1..883e2ef 100644
--- a/BodyshopUploader/Utils/ARMSRoDataModel.cs
+++ b/BodyshopUploader/Utils/ARMSRoDataModel.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using FileHelpers;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
diff --git a/BodyshopUploader/Utils/AppMetaData.cs b/BodyshopUploader/Utils/AppMetaData.cs
index 69e1c94..470fcbe 100644
--- a/BodyshopUploader/Utils/AppMetaData.cs
+++ b/BodyshopUploader/Utils/AppMetaData.cs
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
using System.Windows;
using System.IO;
using RestSharp;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class AppMetaData
{
@@ -22,7 +22,7 @@ namespace BodyshopPartner.Utils
public static Boolean IsTest = false;
private static string workingDirectory = Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location);
- public static string globalScriptsPath = @"C:\ImEX\PartnerScripts";
+ public static string globalScriptsPath = @"C:\Rome\PartnerScripts";
public static RestClient RestClient;
@@ -44,9 +44,9 @@ namespace BodyshopPartner.Utils
FirebaseAPIKey = "AIzaSyBw7_GTy7GtQyfkIRPVrWHEGKfcqeyXw0c";
#else
- graphQlEndpoint = "https://db.imex.online/v1/graphql";
- RestClient = new RestClient("https://api.imex.online");
- FirebaseAPIKey = "AIzaSyDSezy-jGJreo7ulgpLdlpOwAOrgcaEkhU";
+ graphQlEndpoint = "https://db.romeonline.io/v1/graphql";
+ RestClient = new RestClient("https://api.romeonline.io");
+ FirebaseAPIKey = "AIzaSyAuLQR9SV5LsVxjU8wh9hvFLdhcAHU6cxE";
#endif
}
else
diff --git a/BodyshopUploader/Utils/ApplicationExceptionHandler.cs b/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
index 0509c67..6b5bca4 100644
--- a/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
+++ b/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class ApplicationExceptionHandler
{
diff --git a/BodyshopUploader/Utils/Auth.cs b/BodyshopUploader/Utils/Auth.cs
index d7cc09c..1882d15 100644
--- a/BodyshopUploader/Utils/Auth.cs
+++ b/BodyshopUploader/Utils/Auth.cs
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
using Firebase.Auth;
using System.Timers;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class Auth
{
diff --git a/BodyshopUploader/Utils/BaseModel.cs b/BodyshopUploader/Utils/BaseModel.cs
index efa1215..554b994 100644
--- a/BodyshopUploader/Utils/BaseModel.cs
+++ b/BodyshopUploader/Utils/BaseModel.cs
@@ -3,7 +3,7 @@ using System.ComponentModel;
using System.Runtime.CompilerServices;
-namespace BodyshopPartner
+namespace RomeOnlinePartner
{
public class BaseModel : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Utils/BaseViewModel.cs b/BodyshopUploader/Utils/BaseViewModel.cs
index 6a9c38b..89807ff 100644
--- a/BodyshopUploader/Utils/BaseViewModel.cs
+++ b/BodyshopUploader/Utils/BaseViewModel.cs
@@ -2,7 +2,7 @@
using System.ComponentModel;
using System.Runtime.CompilerServices;
-namespace BodyshopPartner
+namespace RomeOnlinePartner
{
public abstract class BaseViewModel : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Utils/CIECAMonitor.cs b/BodyshopUploader/Utils/CIECAMonitor.cs
index fd0629d..fe13e3e 100644
--- a/BodyshopUploader/Utils/CIECAMonitor.cs
+++ b/BodyshopUploader/Utils/CIECAMonitor.cs
@@ -4,9 +4,9 @@ using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using BodyshopPartner.Models;
+using RomeOnlinePartner.Models;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public class CIECAMonitor : FileSystemWatcher
{
diff --git a/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs b/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
index d74f96e..fdedfad 100644
--- a/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
+++ b/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
@@ -8,7 +8,7 @@ using System.Threading.Tasks;
using DotNetDBF;
using Newtonsoft.Json.Linq;
-namespace BodyshopPartner.Utils.Decoder
+namespace RomeOnlinePartner.Utils.Decoder
{
class EstimateDecoder
{
diff --git a/BodyshopUploader/Utils/DiskScan.cs b/BodyshopUploader/Utils/DiskScan.cs
index 61bff68..37085c5 100644
--- a/BodyshopUploader/Utils/DiskScan.cs
+++ b/BodyshopUploader/Utils/DiskScan.cs
@@ -1,4 +1,4 @@
-using BodyshopPartner.Models;
+using RomeOnlinePartner.Models;
using System;
using System.Collections.Generic;
using System.IO;
@@ -6,7 +6,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json.Linq;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class DiskScan
{
diff --git a/BodyshopUploader/Utils/GraphQL.cs b/BodyshopUploader/Utils/GraphQL.cs
index ed5e6b7..a47a160 100644
--- a/BodyshopUploader/Utils/GraphQL.cs
+++ b/BodyshopUploader/Utils/GraphQL.cs
@@ -11,7 +11,7 @@ using System.Net.Http;
using Newtonsoft;
using Newtonsoft.Json.Linq;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class GraphQL
{
diff --git a/BodyshopUploader/Utils/Growls/GrowlNotification.xaml b/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
index d3c288a..04c503d 100644
--- a/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
+++ b/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
@@ -1,9 +1,9 @@
-
{
- hlog("Received a QuickBooks request from ImEX.online");
+ hlog("Received a QuickBooks request from Rome Online");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -41,7 +41,7 @@ namespace BodyshopPartner.Utils
//Pinging based routes.
Route.Add("/ping/", (req, res, props) =>
{
- hlog("Received a ping from ImEX.online");
+ hlog("Received a ping from Rome Online");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -52,7 +52,7 @@ namespace BodyshopPartner.Utils
//FileScanning Routes
Route.Add("/scan/", (req, res, props) =>
{
- hlog("Received a scan request from ImEX.online");
+ hlog("Received a scan request from Rome Online");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -61,7 +61,7 @@ namespace BodyshopPartner.Utils
, "POST");
Route.Add("/import/", (req, res, props) =>
{
- hlog("Received an import request from ImEX.online");
+ hlog("Received an import request from Rome Online");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -71,7 +71,7 @@ namespace BodyshopPartner.Utils
Route.Add("/oec/", (req, res, props) =>
{
- hlog("Received an OEC from ImEX.online");
+ hlog("Received an OEC from Rome Online");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -108,17 +108,17 @@ namespace BodyshopPartner.Utils
hlog = HttpLogger;
try
{
- hlog("ImEX Online connection server starting...");
+ hlog("Rome Online connection server starting...");
HttpServer.ListenAsync(1337, token, Route.OnHttpRequestAsync).Wait();
}
catch (Exception Ex)
{
logger.Fatal("Unable to start HTTP server. " + Ex.ToString());
- hlog("ImEX Online connection server could not start. Please restart the partner to try again.");
+ hlog("Rome Online connection server could not start. Please restart the partner to try again.");
App.Current.Dispatcher.Invoke(() =>
{
- string msg = "Unable to connect to ImEX Online Web App. Please ensure your firewall allows the connection.";
+ string msg = "Unable to connect to Rome Online Web App. Please ensure your firewall allows the connection.";
Utils.Notifications.notifier.ShowError(msg);
});
Utils.SquirrelAwareHelper.AddHttpExcetion();
@@ -166,7 +166,7 @@ namespace BodyshopPartner.Utils
{
try
{
- hlog("Processing QuickBooks request. ImEX Online Record ID:" + request.Id);
+ hlog("Processing QuickBooks request. Rome Online Record ID:" + request.Id);
XDocument response = XDocument.Parse(QuickBooksInterop.ProcessQBXmlRequestUnManaged(request.QbXML));
QbXmlResponse ResponseStatus = QuickBooksInterop.ParseResponseXml(response);
diff --git a/BodyshopUploader/Utils/JobProcessingQueue.cs b/BodyshopUploader/Utils/JobProcessingQueue.cs
index a616dca..d5ba11b 100644
--- a/BodyshopUploader/Utils/JobProcessingQueue.cs
+++ b/BodyshopUploader/Utils/JobProcessingQueue.cs
@@ -5,14 +5,14 @@ using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
-using BodyshopPartner.Utils;
-using BodyshopPartner.Models;
-using BodyshopPartner.Utils.Growls;
+using RomeOnlinePartner.Utils;
+using RomeOnlinePartner.Models;
+using RomeOnlinePartner.Utils.Growls;
using GraphQL;
using Newtonsoft.Json.Linq;
using ToastNotifications.Messages;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class JobProcessingQueue
{
diff --git a/BodyshopUploader/Utils/JsonConverter.cs b/BodyshopUploader/Utils/JsonConverter.cs
index 7815ed0..9cb3b4b 100644
--- a/BodyshopUploader/Utils/JsonConverter.cs
+++ b/BodyshopUploader/Utils/JsonConverter.cs
@@ -7,7 +7,7 @@ using System.Reflection;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
class JsonPathConverter : JsonConverter
{
diff --git a/BodyshopUploader/Utils/JsonExtensions.cs b/BodyshopUploader/Utils/JsonExtensions.cs
index 4f23e05..2f2bb83 100644
--- a/BodyshopUploader/Utils/JsonExtensions.cs
+++ b/BodyshopUploader/Utils/JsonExtensions.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class JsonExtensions
{
diff --git a/BodyshopUploader/Utils/LoginHelpers.cs b/BodyshopUploader/Utils/LoginHelpers.cs
index cb2abb9..5953af4 100644
--- a/BodyshopUploader/Utils/LoginHelpers.cs
+++ b/BodyshopUploader/Utils/LoginHelpers.cs
@@ -6,7 +6,7 @@ using System.Security;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class LoginHelpers
{
diff --git a/BodyshopUploader/Utils/Notifications.cs b/BodyshopUploader/Utils/Notifications.cs
index e4b58d8..751f2e1 100644
--- a/BodyshopUploader/Utils/Notifications.cs
+++ b/BodyshopUploader/Utils/Notifications.cs
@@ -9,7 +9,7 @@ using ToastNotifications.Position;
using ToastNotifications.Messages;
using System.Windows;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class Notifications
{
diff --git a/BodyshopUploader/Utils/OEConnection.cs b/BodyshopUploader/Utils/OEConnection.cs
index 69454e2..1e8a43f 100644
--- a/BodyshopUploader/Utils/OEConnection.cs
+++ b/BodyshopUploader/Utils/OEConnection.cs
@@ -8,7 +8,7 @@ using System.Threading.Tasks;
using DotNetDBF;
using Newtonsoft.Json.Linq;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class OEConnection
{
diff --git a/BodyshopUploader/Utils/PPGMixData.cs b/BodyshopUploader/Utils/PPGMixData.cs
index e699c34..9f342f5 100644
--- a/BodyshopUploader/Utils/PPGMixData.cs
+++ b/BodyshopUploader/Utils/PPGMixData.cs
@@ -10,7 +10,7 @@ using System.IO;
using System.Timers;
using RestSharp;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class PPGMixData
{
@@ -194,7 +194,7 @@ v_paint_codes
new XElement("TransactionDate", DateTime.Now.ToString("yyyy-MM-hh:mm:ss"))
),
new XElement("Product",
- new XElement("Name", "ImEX Online"),
+ new XElement("Name", "Rome Online"),
new XElement("Version", null)
)
diff --git a/BodyshopUploader/Utils/PowerModeEventHandler.cs b/BodyshopUploader/Utils/PowerModeEventHandler.cs
index 2d7bccc..e99385d 100644
--- a/BodyshopUploader/Utils/PowerModeEventHandler.cs
+++ b/BodyshopUploader/Utils/PowerModeEventHandler.cs
@@ -6,7 +6,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class PowerModeEventHandler
{
diff --git a/BodyshopUploader/Utils/Queries/JobsQueries.cs b/BodyshopUploader/Utils/Queries/JobsQueries.cs
index edcfb0c..40ccd47 100644
--- a/BodyshopUploader/Utils/Queries/JobsQueries.cs
+++ b/BodyshopUploader/Utils/Queries/JobsQueries.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils.Queries
+namespace RomeOnlinePartner.Utils.Queries
{
class JobsQueries
{
diff --git a/BodyshopUploader/Utils/Queries/VehicleQueries.cs b/BodyshopUploader/Utils/Queries/VehicleQueries.cs
index d29d03b..45f831a 100644
--- a/BodyshopUploader/Utils/Queries/VehicleQueries.cs
+++ b/BodyshopUploader/Utils/Queries/VehicleQueries.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.Utils.Queries
+namespace RomeOnlinePartner.Utils.Queries
{
public static class VehicleQueries
{
diff --git a/BodyshopUploader/Utils/QuickBooksInterop.cs b/BodyshopUploader/Utils/QuickBooksInterop.cs
index edfd69a..93d69f9 100644
--- a/BodyshopUploader/Utils/QuickBooksInterop.cs
+++ b/BodyshopUploader/Utils/QuickBooksInterop.cs
@@ -6,12 +6,12 @@ using System.Text;
using System.Threading.Tasks;
using System.Xml;
using System.Xml.Linq;
-using BodyshopPartner.Utils.Growls;
+using RomeOnlinePartner.Utils.Growls;
using Interop.QBFC13;
using Interop.QBXMLRP2;
using ToastNotifications.Messages;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class QuickBooksInterop
{
@@ -20,8 +20,8 @@ namespace BodyshopPartner.Utils
private static RequestProcessor2 rp;
private static string maxVersion;
private static QBFileMode mode = QBFileMode.qbFileOpenDoNotCare;
- private static string appID = "ImEXBSP";
- private static string appName = "BodyshopPartner";
+ private static string appID = "RomePartner";
+ private static string appName = "RomeOnlinePartner";
private static GrowlNotification Growler;
public static void ConnectToQuickBooks()
diff --git a/BodyshopUploader/Utils/RelayCommand.cs b/BodyshopUploader/Utils/RelayCommand.cs
index b92b3a6..44cfade 100644
--- a/BodyshopUploader/Utils/RelayCommand.cs
+++ b/BodyshopUploader/Utils/RelayCommand.cs
@@ -1,7 +1,7 @@
using System;
using System.Windows.Input;
-namespace BodyshopPartner
+namespace RomeOnlinePartner
{
public class RelayCommand : ICommand
{
diff --git a/BodyshopUploader/Utils/ScheduledTaskConfig.cs b/BodyshopUploader/Utils/ScheduledTaskConfig.cs
index d6e5a6c..3054032 100644
--- a/BodyshopUploader/Utils/ScheduledTaskConfig.cs
+++ b/BodyshopUploader/Utils/ScheduledTaskConfig.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using Microsoft.Win32.TaskScheduler;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class ScheduledTaskConfig
{
@@ -19,12 +19,12 @@ namespace BodyshopPartner.Utils
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - Paint Scale Connection Export");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - Paint Scale Connection Export");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection Export");
}
- Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("ImEX Online Partner - Paint Scale Connection Export", QuickTriggerType.Hourly, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\PaintScaleExport.ps1");
+ Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("Rome Online Partner - Paint Scale Connection Export", QuickTriggerType.Hourly, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\PaintScaleExport.ps1");
newTask.Run();
@@ -41,12 +41,12 @@ namespace BodyshopPartner.Utils
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - ARMS");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - ARMS");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - ARMS");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - ARMS");
}
- Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("ImEX Online Partner - ARMS", QuickTriggerType.Daily, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\ArmsExport.ps1");
+ Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("Rome Online Partner - ARMS", QuickTriggerType.Daily, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\ArmsExport.ps1");
newTask.Run();
diff --git a/BodyshopUploader/Utils/Scripts/ArmsExport.ps1 b/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
index 5027ca8..1a8c43e 100644
--- a/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
+++ b/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
@@ -1,7 +1,7 @@
#Verify that the partner is running. If not, strat it.
-if((Get-Process -Name ImEXOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
- & "$Env:USERPROFILE\AppData\Local\ImEXOnlinePartner\ImEXOnlinePartner.exe"
+if((Get-Process -Name RomeOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
+ & "$Env:USERPROFILE\AppData\Local\RomeOnlinePartner\RomeOnlinePartner.exe"
}
$PSversion = $PSVersionTable.PSVersion.Major
@@ -11,7 +11,7 @@ function v2 {
# Post request to the partner to trigger the export.
Invoke-WebRequest -Uri http://localhost:1337/arms/rodata/ -Method POST
#Start the Arms Uploader.
-Start-Process -FilePath "C:\ImEX\Applications\ARMSUploader\ROUpload.exe"
+Start-Process -FilePath "C:\Rome\Applications\ARMSUploader\ROUpload.exe"
}
function v1 {
@@ -23,7 +23,7 @@ ResponseStream = $Response.GetResponseStream()
ReadStream = New-Object System.IO.StreamReader $ResponseStream
#Data=$ReadStream.ReadToEnd()
#Start the Arms Uploader.
-Start-Process -FilePath "C:\ImEX\Applications\ARMSUploader\ROUpload.exe"
+Start-Process -FilePath "C:\Rome\Applications\ARMSUploader\ROUpload.exe"
}
diff --git a/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1 b/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
index ec0795f..d14a984 100644
--- a/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
+++ b/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
@@ -1,7 +1,7 @@
#Verify that the partner is running. If not, strat it.
-if((Get-Process -Name ImEXOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
- & "$Env:USERPROFILE\AppData\Local\ImEXOnlinePartner\ImEXOnlinePartner.exe"
+if((Get-Process -Name RomeOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
+ & "$Env:USERPROFILE\AppData\Local\RomeOnlinePartner\RomeOnlinePartner.exe"
}
$PSversion = $PSVersionTable.PSVersion.Major
diff --git a/BodyshopUploader/Utils/Scripts/ProtocolReg.reg b/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
index 5a0575e..33a481d 100644
--- a/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
+++ b/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
@@ -12,7 +12,7 @@ Windows Registry Editor Version 5.00
[HKEY_CURRENT_USER\Software\Classes\imexmedia\shell\open]
[HKEY_CURRENT_USER\Software\Classes\imexmedia\shell\open\command]
-@="\"C:\\ImEX\\PartnerScripts\\imexmedia.bat\" %1"
+@="\"C:\\Rome\\PartnerScripts\\imexmedia.bat\" %1"
[HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\Edge]
"ExternalProtocolDialogShowAlwaysOpenCheckbox"=dword:00000001
diff --git a/BodyshopUploader/Utils/SquirrelAwareHelper.cs b/BodyshopUploader/Utils/SquirrelAwareHelper.cs
index 5564044..68fd177 100644
--- a/BodyshopUploader/Utils/SquirrelAwareHelper.cs
+++ b/BodyshopUploader/Utils/SquirrelAwareHelper.cs
@@ -9,7 +9,7 @@ using Microsoft.Win32.TaskScheduler;
using System.IO;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class SquirrelAwareHelper
{
@@ -69,10 +69,10 @@ namespace BodyshopPartner.Utils
//The paint scale accidentally got added to all people running v31. This was added to remove it.
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - Paint Scale Connection");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - Paint Scale Connection");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection");
}
}
catch (Exception ex)
@@ -150,10 +150,10 @@ namespace BodyshopPartner.Utils
mgr.RemoveShortcutForThisExe();
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - Paint Scale Connection Export"); //This is the old scale path. This was accidentally added for everyone.
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export"); //This is the old scale path. This was accidentally added for everyone.
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - Paint Scale Connection");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection");
}
}
catch (Exception ex)
@@ -162,10 +162,10 @@ namespace BodyshopPartner.Utils
}
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - Paint Scale Connection Export");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - Paint Scale Connection Export");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection Export");
}
}
catch (Exception ex)
@@ -174,10 +174,10 @@ namespace BodyshopPartner.Utils
}
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ImEX Online Partner - ARMS");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - ARMS");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("ImEX Online Partner - ARMS");
+ TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - ARMS");
}
}
catch (Exception ex)
diff --git a/BodyshopUploader/Utils/TrayIcon.cs b/BodyshopUploader/Utils/TrayIcon.cs
index 3203a0c..cf8b00c 100644
--- a/BodyshopUploader/Utils/TrayIcon.cs
+++ b/BodyshopUploader/Utils/TrayIcon.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public class OpenMainWindowCommand : ICommand
{
diff --git a/BodyshopUploader/Utils/UiConverters.cs b/BodyshopUploader/Utils/UiConverters.cs
index 7e74dda..6175633 100644
--- a/BodyshopUploader/Utils/UiConverters.cs
+++ b/BodyshopUploader/Utils/UiConverters.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public class BoolVisibilityConverter : IValueConverter
{
diff --git a/BodyshopUploader/Utils/UpdateHandler.cs b/BodyshopUploader/Utils/UpdateHandler.cs
index d90bcba..9f84233 100644
--- a/BodyshopUploader/Utils/UpdateHandler.cs
+++ b/BodyshopUploader/Utils/UpdateHandler.cs
@@ -10,7 +10,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows;
-namespace BodyshopPartner.Utils
+namespace RomeOnlinePartner.Utils
{
public static class UpdateHandler
{
@@ -35,7 +35,7 @@ namespace BodyshopPartner.Utils
private static NLog.Logger logger = NLog.LogManager.GetCurrentClassLogger();
- public const string UpdatePath = @"http://partner.imex.online/";
+ public const string UpdatePath = @"http://partner.romeonline.io/";
public static async Task AreUpdatesAvailable()
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.commands.cs b/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
index 2aaa0a5..e267524 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
@@ -2,7 +2,7 @@
using System.Windows;
using System.Windows.Input;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.cs b/BodyshopUploader/ViewModels/LoginViewModel.cs
index a56df03..b55dccc 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using System.Windows;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.props.cs b/BodyshopUploader/ViewModels/LoginViewModel.props.cs
index 3bcc5fa..b988e13 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.props.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.props.cs
@@ -6,7 +6,7 @@ using System.Security;
using System.Text;
using System.Threading.Tasks;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.commands.cs b/BodyshopUploader/ViewModels/MainViewModel.commands.cs
index f172c2e..dbb9ec2 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.commands.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.commands.cs
@@ -2,7 +2,7 @@
using System.Windows;
using System.Windows.Input;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.cs b/BodyshopUploader/ViewModels/MainViewModel.cs
index 41d6391..1a1efea 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.cs
@@ -1,5 +1,5 @@
-using BodyshopPartner.Models;
-using BodyshopPartner.Utils.Growls;
+using RomeOnlinePartner.Models;
+using RomeOnlinePartner.Utils.Growls;
using GraphQL.Client;
using GraphQL;
using Newtonsoft.Json;
@@ -16,7 +16,7 @@ using Firebase.Auth;
using ToastNotifications.Messages;
using Microsoft.Win32;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
@@ -109,7 +109,7 @@ namespace BodyshopPartner.ViewModels
}
- // string msg = "An update to ImEX Online Partner is Available. It will be automatically downloaded and applied.";
+ // string msg = "An update to Rome Online Partner is Available. It will be automatically downloaded and applied.";
// Utils.Notifications.notifier.ShowInformation(msg);
// logger.Debug("Updates are available! Installing.");
// try
@@ -391,7 +391,7 @@ namespace BodyshopPartner.ViewModels
logger.Trace(newLine);
}
- private FirebaseAuthLink al = BodyshopPartner.Utils.Auth.authlink;
+ private FirebaseAuthLink al = RomeOnlinePartner.Utils.Auth.authlink;
public async Task TestGql()
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.props.cs b/BodyshopUploader/ViewModels/MainViewModel.props.cs
index 7c6f475..7f2df56 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.props.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.props.cs
@@ -4,11 +4,11 @@ using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using BodyshopPartner.Utils.Growls;
-using BodyshopPartner.Models;
+using RomeOnlinePartner.Utils.Growls;
+using RomeOnlinePartner.Models;
using System.Reflection;
-namespace BodyshopPartner.ViewModels
+namespace RomeOnlinePartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/Views/Login.xaml b/BodyshopUploader/Views/Login.xaml
index 3d946ba..0754fa1 100644
--- a/BodyshopUploader/Views/Login.xaml
+++ b/BodyshopUploader/Views/Login.xaml
@@ -1,16 +1,16 @@
-
-
diff --git a/BodyshopUploader/Views/Login.xaml.cs b/BodyshopUploader/Views/Login.xaml.cs
index 685300e..6bd9559 100644
--- a/BodyshopUploader/Views/Login.xaml.cs
+++ b/BodyshopUploader/Views/Login.xaml.cs
@@ -13,7 +13,7 @@ using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
-namespace BodyshopPartner.Views
+namespace RomeOnlinePartner.Views
{
///
/// Interaction logic for Login.xaml
diff --git a/BodyshopUploader/Views/Main.xaml b/BodyshopUploader/Views/Main.xaml
index dd1ca71..c1347fc 100644
--- a/BodyshopUploader/Views/Main.xaml
+++ b/BodyshopUploader/Views/Main.xaml
@@ -1,13 +1,13 @@
-
/// Interaction logic for Main.xaml
diff --git a/BodyshopUploader/Properties/Resources.Designer.cs b/BodyshopUploader/Properties/Resources.Designer.cs
index f80c3c4..689c85f 100644
--- a/BodyshopUploader/Properties/Resources.Designer.cs
+++ b/BodyshopUploader/Properties/Resources.Designer.cs
@@ -8,7 +8,7 @@
//
//------------------------------------------------------------------------------
-namespace BodyshopPartner.Properties {
+namespace RomeOnlinePartner.Properties {
using System;
@@ -39,7 +39,7 @@ namespace BodyshopPartner.Properties {
public static global::System.Resources.ResourceManager ResourceManager {
get {
if (object.ReferenceEquals(resourceMan, null)) {
- global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("BodyshopPartner.Properties.Resources", typeof(Resources).Assembly);
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("RomeOnlinePartner.Properties.Resources", typeof(Resources).Assembly);
resourceMan = temp;
}
return resourceMan;
@@ -196,7 +196,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to Browse Paint Scale -> IO Path.
+ /// Looks up a localized string similar to Browse Paint Scale -> RO Path.
///
public static string Label_BrowsePaintScaleImportPath {
get {
@@ -205,7 +205,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to Browse IO-> Paint Scale Path.
+ /// Looks up a localized string similar to Browse RO-> Paint Scale Path.
///
public static string Label_BrowsePaintScalePath {
get {
@@ -268,7 +268,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to Paint Scale -> IO Path.
+ /// Looks up a localized string similar to Paint Scale -> RO Path.
///
public static string Label_PaintScaleImportPath {
get {
@@ -286,7 +286,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to IO ->Paint Scale Path.
+ /// Looks up a localized string similar to RO ->Paint Scale Path.
///
public static string Label_PaintScalePath {
get {
@@ -448,7 +448,7 @@ namespace BodyshopPartner.Properties {
}
///
/// Looks up a localized string similar to Please do not close ImEX Online or ImEX Partner during the connection process..
///
public static string Msg_QbConnection_Msg {
get {
@@ -493,7 +493,7 @@ namespace BodyshopPartner.Properties {
}
///
/// Looks up a localized string similar to Login -ImEX Online Partner.
///
public static string Title_Login {
get {
@@ -502,7 +502,7 @@ namespace BodyshopPartner.Properties {
}
///
/// Looks up a localized string similar to ImEX Online Partner.
///
public static string Title_Login_Header {
get {
@@ -511,7 +511,7 @@ namespace BodyshopPartner.Properties {
}
///
/// Looks up a localized string similar to ImEX Online Partner | ImEX Systems Inc..
///
public static string Title_Main {
get {
@@ -448,7 +448,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to Please do not close ImEX Online or ImEX Partner during the connection process..
+ /// Looks up a localized string similar to Please do not close Rome Online or Rome Partner during the connection process..
///
public static string Msg_QbConnection_Msg {
@@ -493,7 +493,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to Login -ImEX Online Partner.
+ /// Looks up a localized string similar to Login - Rome Online Partner.
///
public static string Title_Login {
@@ -502,7 +502,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to ImEX Online Partner.
+ /// Looks up a localized string similar to Rome Online Partner.
///
public static string Title_Login_Header {
@@ -511,7 +511,7 @@ namespace BodyshopPartner.Properties {
}
///
- /// Looks up a localized string similar to ImEX Online Partner | ImEX Systems Inc..
+ /// Looks up a localized string similar to Rome Online Partner | Rome Technologies.
///
public static string Title_Main {